import { _component, TestRendererResult, TestRendererResultWithStore, Action } from './types';
export declare class TestRenderer {
    private methods;
    constructor(component: any, defaultProps?: object, defaultState?: object);
    /**
     * renders the test component
     * @param {object} props, if undefined will use default props
     * @param {any} children, a react component of the test component children
     * @returns {TestRendererResult}
     */
    render: (props?: object | undefined, children?: _component) => TestRendererResult;
    /**
     * renders the test component with a redux store provider
     * @param {object} props, if undefined will use default props
     * @param {object} state, if undefined will use default state
     * @param {any} children, a react component of the test component children
     * @returns {TestRendererResult}
     */
    renderWithStore: (props?: object | undefined, state?: object | undefined, children?: _component) => TestRendererResultWithStore;
    /**
     * updates state and triggers state to be reflowed by dispatching an action of type TESTING_UPDATE_ACTION
     * @param {object} state, the new state object for the redux store
     * @param {string} actionType, optional actionType to be used instead of TESTING_UPDATE_ACTION
     * @returns {void}
     */
    updateStateWithDispatch: (state: object, actionType?: string | undefined) => void;
    /**
     * wraps the existing test component and wrappers in another component
     * returns an id that can be used with useWrapperProps to update this wrappers props
     * @param {component} component, the wrapper component
     * @param {object} props, optional props for the wrapper
     * @returns {number} this number can be used with useWrapperProps to change wrapper properties for a single test
     */
    addWrapper: (component: _component, props?: object | undefined) => number;
    /**
     * wraps the existing test component and wrappers in a context provider
     * @param {React.Context<any>} context, the context to wrap the component and wrappers with
     * @param {object} value, the value of the context provider
     * @returns {number} this number can be used with useContextValue to change the context value for a single test
     */
    addContextProvider: (context: React.Context<any>, value: object) => number;
    /**
     * wraps the existing test component and wrappers in another component that only lasts for one render
     * returns the test component
     * @param {component} component, the wrapper component
     * @param {object} props, optional props for the wrapper
     * @returns {TestRenderer} chainable
     */
    addTemporaryWrapper: (component: _component, props: object) => TestRenderer;
    /**
     * change a wrappers props for one render
     * returns the test component
     * @param {number} id, the wrappers id returned by addWrapper
     * @param {object} props, new props for the wrapper
     * @returns {TestRenderer} chainable
     */
    useWrapperProps: (id: number, props: object) => TestRenderer;
    /**
     * change a context value for one render
     * returns the test component
     * @param {number} id, the wrappers id returned by addWrapper
     * @param {object} value, new value for the contextProvider
     * @returns {TestRenderer} chainable
     */
    useContextValue: (id: number, value: object) => TestRenderer;
    /**
     * get all of the actions dispatched since the last render
     * @returns {Action[]}
     */
    getAllActions: () => Action[];
    /**
     * get all of the actions dispatched since the last render of a particular type
     * @param {string} actionType
     * @returns {Action[]}
     */
    getActionsOfType: (actionType: string) => Action[];
    /**
     * get the number of actions dispatched
     * @returns {number}
     */
    getCountForAllActions: () => number;
    /**
     * get the number of actions dispatched of a particular type
     * @returns {number}
     */
    getCountForAction: (actionType: string) => number;
}
