"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestRenderer = void 0;
const MethodFactory_1 = require("./MethodFactory");
class TestRenderer {
    constructor(component, defaultProps, defaultState) {
        /**
         * renders the test component
         * @param {object} props, if undefined will use default props
         * @param {any} children, a react component of the test component children
         * @returns {TestRendererResult}
         */
        this.render = (props, children) => this.methods.render(props, children);
        /**
         * renders the test component with a redux store provider
         * @param {object} props, if undefined will use default props
         * @param {object} state, if undefined will use default state
         * @param {any} children, a react component of the test component children
         * @returns {TestRendererResult}
         */
        this.renderWithStore = (props, state, children) => this.methods.renderWithStore(props, state, children);
        /**
         * updates state and triggers state to be reflowed by dispatching an action of type TESTING_UPDATE_ACTION
         * @param {object} state, the new state object for the redux store
         * @param {string} actionType, optional actionType to be used instead of TESTING_UPDATE_ACTION
         * @returns {void}
         */
        this.updateStateWithDispatch = (state, actionType) => this.methods.updateStateWithDispatch(state, actionType);
        /**
         * wraps the existing test component and wrappers in another component
         * returns an id that can be used with useWrapperProps to update this wrappers props
         * @param {component} component, the wrapper component
         * @param {object} props, optional props for the wrapper
         * @returns {number} this number can be used with useWrapperProps to change wrapper properties for a single test
         */
        this.addWrapper = (component, props) => this.methods.addWrapper(component, props);
        /**
         * wraps the existing test component and wrappers in a context provider
         * @param {React.Context<any>} context, the context to wrap the component and wrappers with
         * @param {object} value, the value of the context provider
         * @returns {number} this number can be used with useContextValue to change the context value for a single test
         */
        this.addContextProvider = (context, value) => this.methods.addContextProvider(context, value);
        /**
         * wraps the existing test component and wrappers in another component that only lasts for one render
         * returns the test component
         * @param {component} component, the wrapper component
         * @param {object} props, optional props for the wrapper
         * @returns {TestRenderer} chainable
         */
        this.addTemporaryWrapper = (component, props) => {
            this.methods.addTemporaryWrapper(component, props);
            return this;
        };
        /**
         * change a wrappers props for one render
         * returns the test component
         * @param {number} id, the wrappers id returned by addWrapper
         * @param {object} props, new props for the wrapper
         * @returns {TestRenderer} chainable
         */
        this.useWrapperProps = (id, props) => {
            this.methods.useWrapperProps(id, props);
            return this;
        };
        /**
         * change a context value for one render
         * returns the test component
         * @param {number} id, the wrappers id returned by addWrapper
         * @param {object} value, new value for the contextProvider
         * @returns {TestRenderer} chainable
         */
        this.useContextValue = (id, value) => {
            this.methods.useContextValue(id, value);
            return this;
        };
        /**
         * get all of the actions dispatched since the last render
         * @returns {Action[]}
         */
        this.getAllActions = () => this.methods.getAllActions();
        /**
         * get all of the actions dispatched since the last render of a particular type
         * @param {string} actionType
         * @returns {Action[]}
         */
        this.getActionsOfType = (actionType) => this.methods.getActionsOfType(actionType);
        /**
         * get the number of actions dispatched
         * @returns {number}
         */
        this.getCountForAllActions = () => this.methods.getCountForAllActions();
        /**
         * get the number of actions dispatched of a particular type
         * @returns {number}
         */
        this.getCountForAction = (actionType) => this.methods.getCountForAction(actionType);
        const methodFactory = new MethodFactory_1.MethodFactory(component, defaultProps, defaultState);
        this.methods = methodFactory.all;
    }
}
exports.TestRenderer = TestRenderer;
